@@ -15,6 +15,8 @@ def _commandline():
     parser.add_argument(
         '--nohmm', help='Process trajectory without Hidden Markov Model (HMM)',
         action="store_true")
+    parser.add_argument(
+        '--miso', help='Merge the isomers',type=int, default=0)
     parser.add_argument(
         '--dump', help='Process the LAMMPS dump file', action="store_true")
     parser.add_argument(
@@ -22,7 +24,7 @@ def _commandline():
     parser.add_argument(
         '--nopbc', help='Disable PBC.', action="store_true")
     parser.add_argument(
-        '--cell', '-c', nargs=3, type=float, help='Cell')
+        '--cell', '-c', nargs='+', type=float, help='Cell')
     parser.add_argument(
         '-n', '-np', '--nproc', help='Number of processes', type=int)
     parser.add_argument(
@@ -44,6 +46,7 @@ def _commandline():
     import numpy as np
     ReacNetGenerator(
         inputfilename=args.inputfilename, atomname=args.atomname,
+        miso=args.miso,
         runHMM=not args.nohmm,
         inputfiletype=('lammpsdumpfile' if args.dump else args.type),
         nproc=args.nproc, selectatoms=args.selectatoms,
